@@ -5,11 +5,8 @@ import pytest
 from mock import Mock, patch
 
 import vessl
-from openapi_client.api.apiv1_api import APIV1Api
-from openapi_client.models import (
-    SignInAPIInput,
-    SignInCliConfirmAPIInput,
-)
+from openapi_client.api import APIV1Api
+from openapi_client.models import SignInAPIInput, SignInCliConfirmAPIInput
 from vessl.util.config import VesslConfigLoader
 from vessl.util.exception import VesslApiException
 
