@@ -76,7 +76,7 @@ def read(name: str):
             "Organization": dataset.organization.name,
             "Versioning": dataset.is_version_enabled,
             "Volume ID": dataset.volume_id,
-            "Source": dataset.source.type,
+            "Source": dataset.source.provider,
         }
     )
     print(
@@ -91,7 +91,7 @@ def list():
     print_table(
         datasets,
         ["Name", "Source", "Updated"],
-        lambda x: [x.name, x.source.type, truncate_datetime(x.updated_dt)],
+        lambda x: [x.name, x.source.provider, truncate_datetime(x.updated_dt)],
     )
 
 
