@@ -42,9 +42,7 @@ def read(name: str):
     organization = read_organization(organization_name=name)
     print_data(
         {
-            "ID": organization.id,
             "Name": organization.name,
-            "Region": organization.default_region,
             "Description": organization.description,
         }
     )
@@ -55,8 +53,8 @@ def list():
     organizations = list_organizations()
     print_table(
         organizations,
-        ["ID", "Name", "Region"],
-        lambda x: [x.id, x.name, x.default_region],
+        ["Name"],
+        lambda x: [x.name],
     )
 
 
