@@ -6,6 +6,7 @@ import vessl
 from vessl.cli._base import VesslGroup, vessl_argument
 from vessl.cli._util import (
     Endpoint,
+    format_url,
     generic_prompter,
     print_data,
     print_table,
@@ -25,31 +26,6 @@ def project_name_prompter(
     return prompt_choices("Project", [x.name for x in projects])
 
 
-### Deprecate
-
-# def version_control_project_name_prompter(
-#     ctx: click.Context, param: click.Parameter, value: str,
-# ) -> str:
-#     projects = [p for p in list_projects() if p.type == PROJECT_TYPE_VERSION_CONTROL]
-#     if not projects:
-#         raise click.ClickException(f'No version-control project found.')
-#     return prompt_choices("Project", [x.name for x in projects])
-
-
-# def github_owner_prompter(
-#     ctx: click.Context, param: click.Parameter, value: str,
-# ) -> str:
-#     type = ctx.params.get("type")
-#     if type == PROJECT_TYPE_VERSION_CONTROL:
-#         return click.prompt("Github owner", type=click.STRING)
-
-
-# def github_repo_prompter(ctx: click.Context, param: click.Parameter, value: str) -> str:
-#     type = ctx.params.get("type")
-#     if type == PROJECT_TYPE_VERSION_CONTROL:
-#         return click.prompt("Github repository name", type=click.STRING)
-
-
 @click.command(name="project", cls=VesslGroup)
 def cli():
     pass
@@ -95,7 +71,7 @@ def create(name: str, description: str):
     )
     print(
         f"Created '{project.name}'.\n"
-        f"For more info: {Endpoint.project.format(project.organization.name, project.name)}"
+        f"For more info: {format_url(Endpoint.project.format(project.organization.name, project.name))}"
     )
 
 
@@ -118,7 +94,8 @@ def project_name_callback(
         vessl.vessl_api.set_organization()
 
     try:
-        vessl.vessl_api.set_project(value)
+        project_name = vessl.vessl_api.set_project(value)
+        print(f"Project: {project_name}")
     except InvalidProjectError:
         print("Invalid project. Please choose a project using `vessl configure`.")
         sys.exit(1)
