@@ -36,3 +36,9 @@ def generate_uuid():
         alphabet=list("0123456789abcdefghijklmnopqrstuvwxyz")
     )
     return generated_uuid.random(8)
+
+
+def is_processor_m1():
+    from cpuinfo import get_cpu_info
+
+    return "m1" in get_cpu_info().get("brand_raw").lower()
